USE [igops]
GO

DROP VIEW IF EXISTS cpol_overview_v
GO

DROP VIEW IF EXISTS cpol_review_item_v
GO

DROP VIEW IF EXISTS micro_certification_reviews_v
GO

CREATE VIEW cpol_overview_v AS 
	SELECT 
		cpol.ID,
		cpol.unique_id,
		cpol.NAME,
		cpol.DESCRIPTION,
		cpol.VALIDITY_PERIOD,
		cpol.status,
		cpol.CP_TOTAL_VIOLATION
	FROM CERTIFICATION_POLICY cpol
	WHERE cpol.IS_ACTIVE = '1'
GO

CREATE VIEW cpol_review_item_v AS 
	SELECT 
		cpol.name as cert_policy,
		cpol.UNIQUE_ID as cert_policy_unique_id,
		cpol.ID as cert_policy_id,
		cpol.status,
		rev_def.name as review,
		rev_item.UNIQUE_ACCOUNT_ID,
		rev_item.UNIQUE_USER_ID,
		rev_item.UNIQUE_PERMISSION_ID,
		rev_item.BUSINESS_ROLE_ID,
		rev_def.ID as review_id,
		rev_def.REVIEW_TYPE,
		brole.name as brole,
		brole.UNIQUE_ID as brole_unique_id,
		brole.approval_state AS brole_approval_state,
		rev_item.ROLE_ID,
		MAX(rev_item.FINAL_DECISION_TIME) AS LAST_FINAL_DECISION_TIME,
		MAX(CASE WHEN rev_item.FINAL_DECISION IS NOT NULL AND rev_inst.status != 'CANCELED' THEN rev_inst.END_DATE ELSE NULL END) as LAST_END_DATE_WITH_DECISION,
		MAX(rev_inst.ID) AS LAST_REVIEW_INST
	FROM REVIEW_ITEM rev_item 
		JOIN REVIEW_INSTANCE rev_inst ON rev_inst.ID = rev_item.REVIEW_INSTANCE_ID
		JOIN REVIEW_DEFINITION rev_def ON rev_def.ID = rev_inst.REVIEW_DEFINITION AND rev_def.IS_ACTIVE = '1'
		JOIN CERT_POLICY_REVIEW_DEFS cpol_rev ON cpol_rev.REVIEW_DEFINITION_UNIQUE_ID = rev_def.UNIQUE_REVIEW_DEF_ID
		JOIN CERTIFICATION_POLICY cpol ON cpol.ID = cpol_rev.CERT_POLICY_ID AND cpol.IS_ACTIVE = '1'
		LEFT JOIN BUSINESS_ROLE brole ON brole.ID = rev_item.BUSINESS_ROLE_ID
	GROUP BY  cpol.ID, cpol.UNIQUE_ID ,cpol.name, rev_def.name, rev_item.UNIQUE_USER_ID, rev_item.UNIQUE_ACCOUNT_ID, rev_item.UNIQUE_PERMISSION_ID, rev_item.BUSINESS_ROLE_ID,rev_item.ROLE_ID,brole.UNIQUE_ID, brole.name, cpol.status, rev_def.ID, rev_def.REVIEW_TYPE, brole.approval_state
GO

CREATE VIEW micro_certification_reviews_v AS 
	SELECT
		rem_run.review_instance_id,
		rem_run.policy_id,
		rev_inst.REVIEW_DEFINITION,
		rev_inst.START_DATE,
		rev_inst.END_DATE
	FROM remediation_run rem_run
		JOIN review_instance rev_inst ON rem_run.review_instance_id = rev_inst.ID
	WHERE rem_run.REMEDIATION_TYPE = 'MICRO_CERTIFICATION'
GO

GRANT SELECT ON cpol_overview_v TO ig_report_role
GO

GRANT SELECT ON cpol_review_item_v TO ig_report_role
GO

GRANT SELECT ON micro_certification_reviews_v TO ig_report_role
GO