DROP VIEW IF EXISTS cpol_overview_v;

DROP VIEW IF EXISTS cpol_review_item_v;

DROP VIEW IF EXISTS micro_certification_reviews_v;

CREATE VIEW cpol_overview_v AS 
	SELECT cpol.id,
	    cpol.unique_id,
	    cpol.name,
	    cpol.description,
	    cpol.validity_period,
	    cpol.status,
	    cpol.cp_total_violation
	FROM certification_policy cpol
	WHERE cpol.is_active = true;

CREATE VIEW cpol_review_item_v AS 
	SELECT 
	    cpol.name AS cert_policy,
	    cpol.unique_id AS cert_policy_unique_id,
	    cpol.id AS cert_policy_id,
	    cpol.status,
	    rev_def.name AS review,
	    rev_item.unique_account_id,
	    rev_item.unique_user_id,
	    rev_item.unique_permission_id,
	    rev_item.business_role_id,
	    rev_def.id AS review_id,
	    rev_def.review_type,
	    brole.name AS brole,
	    brole.unique_id AS brole_unique_id,
	    brole.approval_state AS brole_approval_state,
	    rev_item.role_id,
	    max(rev_item.final_decision_time) AS last_final_decision_time,
	    max(CASE WHEN rev_item.final_decision IS NOT NULL AND rev_inst.status != 'CANCELED' THEN rev_inst.end_date ELSE NULL END) AS last_end_date_with_decision,
	    max(rev_inst.id) AS last_review_inst
	FROM review_item rev_item
	    JOIN review_instance rev_inst ON rev_inst.id = rev_item.review_instance_id
	    JOIN review_definition rev_def ON rev_def.id = rev_inst.review_definition AND rev_def.is_active = true
	    JOIN cert_policy_review_defs cpol_rev ON cpol_rev.review_definition_unique_id::text = rev_def.unique_review_def_id::text
	    JOIN certification_policy cpol ON cpol.id = cpol_rev.cert_policy_id AND cpol.is_active = true
	    LEFT JOIN business_role brole ON brole.id = rev_item.business_role_id
	GROUP BY cpol.id, cpol.unique_id, cpol.name, rev_def.name, rev_item.unique_user_id, rev_item.unique_account_id, rev_item.unique_permission_id, rev_item.business_role_id, rev_item.role_id, brole.unique_id, brole.name, cpol.status, rev_def.id, rev_def.review_type, brole.approval_state;

CREATE VIEW micro_certification_reviews_v AS 
	SELECT 
		rem_run.review_instance_id,
		rem_run.policy_id,
		rev_inst.review_definition,
		rev_inst.start_date,
		rev_inst.end_date
	FROM remediation_run rem_run
		JOIN review_instance rev_inst ON rem_run.review_instance_id = rev_inst.id
	WHERE rem_run.remediation_type::text = 'MICRO_CERTIFICATION'::text;

ALTER TABLE cpol_overview_v OWNER TO igops;
GRANT ALL ON TABLE cpol_overview_v TO igops;
GRANT SELECT ON TABLE cpol_overview_v TO ig_report_role;

ALTER TABLE cpol_review_item_v OWNER TO igops;
GRANT ALL ON TABLE cpol_review_item_v TO igops;
GRANT SELECT ON TABLE cpol_review_item_v TO ig_report_role;

ALTER TABLE micro_certification_reviews_v OWNER TO igops;
GRANT ALL ON TABLE micro_certification_reviews_v TO igops;
GRANT SELECT ON TABLE micro_certification_reviews_v TO ig_report_role;